==> RsCMX_Signaling-4.0.120.tar.gz: RsCMX_Signaling-4.0.120/RsCMX_Signaling/Implementations/Configure/Signaling/Lte/Cell/CqiReporting/Sancqi.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SancqiCls:
	"""Sancqi commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sancqi", core, parent)

	def set(self, cell_name: str, enable: bool) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:SANCqi \n
		Snippet: driver.configure.signaling.lte.cell.cqiReporting.sancqi.set(cell_name = '1', enable = False) \n
		Configures the parameter 'simultaneousAckNackAndCQI', signaled to the UE. \n
			:param cell_name: No help available
			:param enable: ON: simultaneous transmission allowed OFF: not allowed
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('enable', enable, DataType.Boolean))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:SANCqi {param}'.rstrip())

	def get(self, cell_name: str) -> bool:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:SANCqi \n
		Snippet: value: bool = driver.configure.signaling.lte.cell.cqiReporting.sancqi.get(cell_name = '1') \n
		Configures the parameter 'simultaneousAckNackAndCQI', signaled to the UE. \n
			:param cell_name: No help available
			:return: enable: ON: simultaneous transmission allowed OFF: not allowed"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:SANCqi? {param}')
		return Conversions.str_to_bool(response)

==> RsCMX_Signaling-7.70.0.tar.gz: RsCMX_Signaling-7.70.0/RsCMX_Signaling/Implementations/Configure/Signaling/Lte/Cell/CqiReporting/Sancqi.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SancqiCls:
	"""Sancqi commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sancqi", core, parent)

	def set(self, cell_name: str, enable: bool) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:SANCqi \n
		Snippet: driver.configure.signaling.lte.cell.cqiReporting.sancqi.set(cell_name = 'abc', enable = False) \n
		Configures the parameter 'simultaneousAckNackAndCQI', signaled to the UE. \n
			:param cell_name: No help available
			:param enable: ON: simultaneous transmission allowed OFF: not allowed
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('enable', enable, DataType.Boolean))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:SANCqi {param}'.rstrip())

	def get(self, cell_name: str) -> bool:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:SANCqi \n
		Snippet: value: bool = driver.configure.signaling.lte.cell.cqiReporting.sancqi.get(cell_name = 'abc') \n
		Configures the parameter 'simultaneousAckNackAndCQI', signaled to the UE. \n
			:param cell_name: No help available
			:return: enable: ON: simultaneous transmission allowed OFF: not allowed"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:SANCqi? {param}')
		return Conversions.str_to_bool(response)
